create_table_todays_timelogs

Function create_table_todays_timelogs 

fn create_table_todays_timelogs(time_logs: &[TimeLog]) -> Option<Table>
Creates a table showing the time logs from today’s date. If there are no time logs, None is returned.